@@ -1,3 +1,4 @@
+from .broker import Broker, QueuedTask
 from .constants import TaskPriority, TaskState
 from .consumer import TaskConsumer, TaskManager
 from .crontab import crontab
@@ -10,6 +11,7 @@ from .task import (
     TaskDecoratorError,
     TaskExecutor,
     TaskRunError,
+    create_task_app,
     task,
 )
 from .task_run import TaskRun
@@ -28,6 +30,9 @@ __all__ = [
     "TaskManager",
     "TaskConsumer",
     "TaskRun",
+    "QueuedTask",
+    "Broker",
+    "create_task_app",
     "crontab",
     "every",
 ]
