@@ -1,4 +1,5 @@
 import asyncio
+import os
 from datetime import datetime
 from typing import Dict
 
@@ -17,7 +18,7 @@ class TaskScheduler(TaskManager):
 
 
 class ScheduleTasks(Node):
-    heartbeat = 0.1
+    heartbeat = float(os.getenv("TASK_SCHEDULER_HEARTBEAT", "0.1"))
 
     def __init__(self, task_manager: TaskScheduler) -> None:
         super().__init__()
@@ -25,8 +26,13 @@ class ScheduleTasks(Node):
         self.last_run: Dict[str, CronRun] = {}
 
     async def tick(self) -> None:
+        if not self.task_manager.config.schedule_tasks:
+            return
         now = datetime.utcnow()
-        for task in self.task_manager.registry.periodic():
+        periodic_tasks = await self.task_manager.broker.filter_tasks(
+            scheduled=True, enabled=True
+        )
+        for task in periodic_tasks:
             run = task.schedule(now, self.last_run.get(task.name))
             if run:
                 self.last_run[task.name] = run
