@@ -1,5 +1,6 @@
 import asyncio
 from dataclasses import dataclass, field
+from typing import Any
 
 from .broker import TaskRun
 
@@ -9,6 +10,6 @@ class WaitFor:
     run_id: str
     waiter: asyncio.Future = field(default_factory=asyncio.Future)
 
-    def __call__(self, task_run: TaskRun, _):
+    def __call__(self, task_run: TaskRun, _: Any) -> None:
         if task_run.id == self.run_id:
             self.waiter.set_result(task_run)
